[![Tests](https://github.com/science-for-democracy/mapof-marriages/actions/workflows/python-tests.yml/badge.svg)](https://github.com/science-for-democracy/mapof-marriages/actions/workflows/python-tests.yml)
[![codecov](https://codecov.io/gh/science-for-democracy/mapof-marriages/graph/badge.svg?token=MB6YOJMFIS)](https://codecov.io/gh/science-for-democracy/mapof-marriages)

# Mapof-marriages
This pacakge is a plugin for [Mapof](https://pypi.org/project/mapof/) extending
it with capabilities of drawing maps of instances of the Stable Marriage
problem.

For the most recent version of Mapof, visit its [git
repo](https://pypi.org/project/mapof/).

# Installation
For a simple installation, type
`pip install mapof-marriages`
in the console.

For more complicated variants of installation, refer to the [readme of
Mapof](https://github.com/science-for-democracy/mapof).

# Acknowledgments

This project is part of the [PRAGMA project](https://home.agh.edu.pl/~pragma/)
which has received funding from the [European Research Council
(ERC)](https://home.agh.edu.pl/~pragma/) under the European Union’s Horizon 2020
research and innovation programme ([grant agreement No
101002854](https://erc.easme-web.eu/?p=101002854)).



